@@ -1,12 +1,11 @@
 from .abc import AbstractAuthorizationPolicy, AbstractIdentityPolicy
-from .api import (authorized_userid, forget, has_permission,
-                  is_anonymous, login_required, permits, remember,
-                  setup, check_authorized, check_permission)
+from .api import (authorized_userid, check_authorized, check_permission, forget,
+                  is_anonymous, permits, remember, setup)
 from .cookies_identity import CookiesIdentityPolicy
-from .session_identity import SessionIdentityPolicy
 from .jwt_identity import JWTIdentityPolicy
+from .session_identity import SessionIdentityPolicy
 
-__version__ = '0.4.0'
+__version__ = '0.5.0'
 
 
 __all__ = ('AbstractIdentityPolicy', 'AbstractAuthorizationPolicy',
@@ -14,5 +13,4 @@ __all__ = ('AbstractIdentityPolicy', 'AbstractAuthorizationPolicy',
            'JWTIdentityPolicy',
            'remember', 'forget', 'authorized_userid',
            'permits', 'setup', 'is_anonymous',
-           'login_required', 'has_permission',
            'check_authorized', 'check_permission')
