@@ -4,6 +4,9 @@ aiohttp_session.setup() should be called on application initialization
 to configure aiohttp_session properly.
 """
 
+from typing import Optional
+
+from aiohttp import web
 try:
     from aiohttp_session import get_session
     HAS_AIOHTTP_SESSION = True
@@ -15,21 +18,22 @@ from .abc import AbstractIdentityPolicy
 
 class SessionIdentityPolicy(AbstractIdentityPolicy):
 
-    def __init__(self, session_key='AIOHTTP_SECURITY'):
+    def __init__(self, session_key: str = 'AIOHTTP_SECURITY'):
         self._session_key = session_key
 
         if not HAS_AIOHTTP_SESSION:  # pragma: no cover
             raise ImportError(
                 'SessionIdentityPolicy requires `aiohttp_session`')
 
-    async def identify(self, request):
+    async def identify(self, request: web.Request) -> Optional[str]:
         session = await get_session(request)
         return session.get(self._session_key)
 
-    async def remember(self, request, response, identity, **kwargs):
+    async def remember(self, request: web.Request, response: web.StreamResponse,
+                       identity: str, **kwargs: None) -> None:
         session = await get_session(request)
         session[self._session_key] = identity
 
-    async def forget(self, request, response):
+    async def forget(self, request: web.Request, response: web.StreamResponse) -> None:
         session = await get_session(request)
         session.pop(self._session_key, None)
